==> cdktf_cdktf_provider_azurerm-0.5.60-py3-none-any.whl: package/lib/security-center-server-vulnerability-assessment.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SecurityCenterServerVulnerabilityAssessmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#hybrid_machine_id SecurityCenterServerVulnerabilityAssessment#hybrid_machine_id}
    */
    readonly hybridMachineId?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#virtual_machine_id SecurityCenterServerVulnerabilityAssessment#virtual_machine_id}
    */
    readonly virtualMachineId?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#timeouts SecurityCenterServerVulnerabilityAssessment#timeouts}
    */
    readonly timeouts?: SecurityCenterServerVulnerabilityAssessmentTimeouts;
}
export interface SecurityCenterServerVulnerabilityAssessmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#create SecurityCenterServerVulnerabilityAssessment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#delete SecurityCenterServerVulnerabilityAssessment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#read SecurityCenterServerVulnerabilityAssessment#read}
    */
    readonly read?: string;
}
export declare function securityCenterServerVulnerabilityAssessmentTimeoutsToTerraform(struct?: SecurityCenterServerVulnerabilityAssessmentTimeoutsOutputReference | SecurityCenterServerVulnerabilityAssessmentTimeouts | cdktf.IResolvable): any;
export declare class SecurityCenterServerVulnerabilityAssessmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): SecurityCenterServerVulnerabilityAssessmentTimeouts | undefined;
    set internalValue(value: SecurityCenterServerVulnerabilityAssessmentTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment azurerm_security_center_server_vulnerability_assessment}
*/
export declare class SecurityCenterServerVulnerabilityAssessment extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment azurerm_security_center_server_vulnerability_assessment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SecurityCenterServerVulnerabilityAssessmentConfig = {}
    */
    constructor(scope: Construct, id: string, config?: SecurityCenterServerVulnerabilityAssessmentConfig);
    private _hybridMachineId?;
    get hybridMachineId(): string;
    set hybridMachineId(value: string);
    resetHybridMachineId(): void;
    get hybridMachineIdInput(): string | undefined;
    get id(): string;
    private _virtualMachineId?;
    get virtualMachineId(): string;
    set virtualMachineId(value: string);
    resetVirtualMachineId(): void;
    get virtualMachineIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): SecurityCenterServerVulnerabilityAssessmentTimeoutsOutputReference;
    putTimeouts(value: SecurityCenterServerVulnerabilityAssessmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): SecurityCenterServerVulnerabilityAssessmentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.6.17-py3-none-any.whl: package/lib/security-center-server-vulnerability-assessment.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SecurityCenterServerVulnerabilityAssessmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#hybrid_machine_id SecurityCenterServerVulnerabilityAssessment#hybrid_machine_id}
    */
    readonly hybridMachineId?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#virtual_machine_id SecurityCenterServerVulnerabilityAssessment#virtual_machine_id}
    */
    readonly virtualMachineId?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#timeouts SecurityCenterServerVulnerabilityAssessment#timeouts}
    */
    readonly timeouts?: SecurityCenterServerVulnerabilityAssessmentTimeouts;
}
export interface SecurityCenterServerVulnerabilityAssessmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#create SecurityCenterServerVulnerabilityAssessment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#delete SecurityCenterServerVulnerabilityAssessment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment#read SecurityCenterServerVulnerabilityAssessment#read}
    */
    readonly read?: string;
}
export declare function securityCenterServerVulnerabilityAssessmentTimeoutsToTerraform(struct?: SecurityCenterServerVulnerabilityAssessmentTimeoutsOutputReference | SecurityCenterServerVulnerabilityAssessmentTimeouts | cdktf.IResolvable): any;
export declare class SecurityCenterServerVulnerabilityAssessmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SecurityCenterServerVulnerabilityAssessmentTimeouts | undefined;
    set internalValue(value: SecurityCenterServerVulnerabilityAssessmentTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment azurerm_security_center_server_vulnerability_assessment}
*/
export declare class SecurityCenterServerVulnerabilityAssessment extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_security_center_server_vulnerability_assessment";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/security_center_server_vulnerability_assessment azurerm_security_center_server_vulnerability_assessment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SecurityCenterServerVulnerabilityAssessmentConfig = {}
    */
    constructor(scope: Construct, id: string, config?: SecurityCenterServerVulnerabilityAssessmentConfig);
    private _hybridMachineId?;
    get hybridMachineId(): string;
    set hybridMachineId(value: string);
    resetHybridMachineId(): void;
    get hybridMachineIdInput(): string | undefined;
    get id(): string;
    private _virtualMachineId?;
    get virtualMachineId(): string;
    set virtualMachineId(value: string);
    resetVirtualMachineId(): void;
    get virtualMachineIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): SecurityCenterServerVulnerabilityAssessmentTimeoutsOutputReference;
    putTimeouts(value: SecurityCenterServerVulnerabilityAssessmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): SecurityCenterServerVulnerabilityAssessmentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
